@@ -13,7 +13,7 @@ $|=1;
 #binmode(STDERR, ":encoding(console_out)");
 
 my %opt;
-getopt( 'fsdhup', \%opt );
+getopt( 'fsdhupm', \%opt );
 
 send_novel(%opt) if($opt{d});
 
@@ -21,9 +21,13 @@ send_novel(%opt) if($opt{d});
 sub send_novel {
     my (%opt) = @_;
 
-    my $cmd =qq[sendEmail -u '' -m 'novel' -f $opt{s} -t $opt{d} -a $opt{f} -vv];
+    $opt{f} = decode(locale => $opt{f});
+    $opt{m} = decode(locale => $opt{m} || 'novel');
 
-    $cmd.= qq[ -s $opt{h} -xu $opt{u} -xp $opt{p}] if($opt{h});
+    my $cmd =qq[sendEmail -u '$opt{m}' -m '$opt{m}' -f '$opt{s}' -t '$opt{d}' -a '$opt{f}' -vv];
+    $cmd.= qq[ -s '$opt{h}' -xu '$opt{u}' -xp '$opt{p}'] if($opt{h});
+
+    $cmd=encode(locale=>$cmd);
 
     system($cmd);
 }
